@@ -414,6 +414,31 @@ QString ScriptingService::callInsertAttachmentHook(QFile *file,
     return markdownText;
 }
 
+/**
+ * Calls the workspaceSwitchedHook function for all script components
+ * This function is called when workspaces are switched
+ *
+ * @param oldUuid old uuid of workspace
+ * @param newUuid new uuid of workspace
+ */
+void ScriptingService::callWorkspaceSwitchedHook(const QString &oldUuid, const QString &newUuid) {
+    QMapIterator<int, ScriptComponent> i(_scriptComponents);
+
+    while (i.hasNext()) {
+        i.next();
+        ScriptComponent scriptComponent = i.value();
+
+        if (methodExistsForObject(
+                scriptComponent.object,
+                QStringLiteral(
+                    "workspaceSwitchedHook(QVariant,QVariant)"))) {
+            QMetaObject::invokeMethod(
+                scriptComponent.object, "workspaceSwitchedHook",
+                Q_ARG(QVariant, oldUuid), Q_ARG(QVariant, newUuid));
+        }
+    }
+}
+
 /**
  * Calls the noteTaggingHook function for all script components
  * This function is called when tags are added to, removed from or renamed in
@@ -1808,18 +1833,24 @@ void ScriptingService::setClipboardText(const QString &text, bool asHtml) {
  * Sets the current note if the note is visible in the note list
  *
  * @param note NoteApi note to jump to
+ * @param asTab bool if true the note will be opened in a new tab if not already open
  */
-void ScriptingService::setCurrentNote(NoteApi *note) {
+void ScriptingService::setCurrentNote(NoteApi *note, bool asTab) {
     MetricsService::instance()->sendVisitIfEnabled(
         QStringLiteral("scripting/") % QString(__func__));
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
     if (mainWindow != nullptr) {
-        mainWindow->setCurrentNoteFromNoteId(note->getId());
+        if (asTab) {
+            mainWindow->openNoteInTab(Note::fetch(note->getId()));
+        } else {
+            mainWindow->setCurrentNoteFromNoteId(note->getId());
+        }
     }
 #else
     Q_UNUSED(note)
+    Q_UNUSED(asTab)
 #endif
 }
 
