@@ -40,6 +40,7 @@ class ScriptingService : public QObject {
     void initComponents();
     QString callInsertMediaHook(QFile *file, QString markdownText);
     QString callInsertAttachmentHook(QFile *file, QString markdownText);
+    void callWorkspaceSwitchedHook(const QString &oldUuid, const QString &newUuid);
     QVariant callNoteTaggingHook(const Note &note, const QString &action,
                                  const QString &tagName = QString(),
                                  const QString &newTagName = QString());
@@ -106,7 +107,7 @@ class ScriptingService : public QObject {
                                           int ignoreNoteId = 0,
                                           int noteSubFolderId = -1);
     Q_INVOKABLE void setClipboardText(const QString &text, bool asHtml = false);
-    Q_INVOKABLE void setCurrentNote(NoteApi *note);
+    Q_INVOKABLE void setCurrentNote(NoteApi *note, bool asTab = false);
 
     Q_INVOKABLE void informationMessageBox(const QString &text,
                                            const QString &title = QString());
